# ProjectModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**attributes_scheme** | [**[CustomAttributeModel], none_type**](CustomAttributeModel.md) |  | [optional] 
**test_plans_attributes_scheme** | [**[CustomAttributeModel], none_type**](CustomAttributeModel.md) |  | [optional] 
**test_cases_count** | **int, none_type** |  | [optional] 
**shared_steps_count** | **int, none_type** |  | [optional] 
**check_lists_count** | **int, none_type** |  | [optional] 
**auto_tests_count** | **int, none_type** |  | [optional] 
**is_favorite** | **bool** | Property is used to filter favourite projects | [optional] 
**is_deleted** | **bool** |  | [optional] 
**created_date** | **datetime, none_type** |  | [optional] 
**modified_date** | **datetime, none_type** |  | [optional] 
**created_by_id** | **str** |  | [optional] 
**modified_by_id** | **str, none_type** |  | [optional] 
**global_id** | **int** |  | [optional] 
**id** | **str** |  | [optional] 
**description** | **str, none_type** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


